Modbus response messages and validation against requests.
Since the responses all implement zerocopy::FromBytes, they can be read
directly from a byte buffer. However, this also means that there is no
validation of the response data, not even the CRC checksum.
Structs
- Read
Holdings - Read holding registers response
- Read
Holdings Builder - Read
Inputs - Read input registers response
- Write
Holding - Write single holding register response
- Write
Holdings - Write multiple holding registers response
Traits
- Response
- Trait for Modbus response messages that can be validated against requests.