Response

Trait Response 

pub trait Response<Request> {
    type Data;

    // Required method
    fn into_data(self, request: &Request) -> Result<Self::Data, ValidationError>;
}
Trait for Modbus response messages that can be validated against requests.

Required Associated Types

type Data

The type of data extracted from the response.

Required Methods

fn into_data(self, request: &Request) -> Result<Self::Data, ValidationError>

Validate the response against a given request and extract the data on success.

Implementors