Frame

Struct Frame 

pub struct Frame<T> { /* private fields */ }
A complete Modbus frame.

Implementations

Source

impl<T> Frame<T>

pub fn new(unit_id: u8, pdu: T) -> Self
where T: Pdu,

Creates a new frame with the given unit ID and PDU and calculates the CRC.

pub const fn builder(unit_id: u8) -> FrameBuilder<T>
where T: Pdu,

Creates a new FrameBuilder.

pub fn validate_crc(&self) -> Result<(), CrcError>

Validates the CRC of the frame. Self::into_data will also validate the CRC, so in most cases you should not need to call this method directly.

pub fn unit_id(&self) -> u8

Returns the unit ID of the frame.

pub fn pdu(&self) -> &T

Returns a reference to the PDU of the frame.

pub fn into_data<Request>( self, request: &Frame<Request>, ) -> Result<T::Data, ValidationError>
where T: Response<Request>,

Validate the frame against the given request, returning the data if valid.

pub fn view(&self) -> FrameView<'_>

Upcast the frame to an FrameView.