FrameBuilder

Struct FrameBuilder 

pub struct FrameBuilder<T> { /* private fields */ }
A builder for Frames.

Implementations

Source

impl<T: Pdu> FrameBuilder<T>

pub const fn with_pdu(unit_id: u8, pdu: T) -> Self

Creates a new builder with the given unit ID and PDU.

This is different from Frame::new in that no CRC is calculated at this point.

pub const fn new(unit_id: u8) -> Self

Creates a new builder with the given unit ID and default PDU value.

pub const fn set_unit_id(&mut self, unit_id: u8)

Changes the unit ID.

pub fn build_ref(&mut self) -> &mut Frame<T>

Build a frame but don’t move it out of the builder, so that the builder can be recycled.

pub fn build(self) -> Frame<T>

Build a frame (calculate its CRC) and move it out of the builder.

pub fn pdu(&self) -> &T

Get a reference to the inner PDU.

pub fn pdu_mut(&mut self) -> &mut T

Access the inner PDU mutably.