pub struct Frame<T> { /* private fields */ }Expand description
A complete Modbus frame.
Implementations
Sourceimpl<T> Frame<T>
impl<T> Frame<T>
Sourcepub fn new(unit_id: u8, pdu: T) -> Selfwhere
T: Pdu,
pub fn new(unit_id: u8, pdu: T) -> Selfwhere
T: Pdu,
Creates a new frame with the given unit ID and PDU and calculates the CRC.
Sourcepub const fn builder(unit_id: u8) -> FrameBuilder<T>where
T: Pdu,
pub const fn builder(unit_id: u8) -> FrameBuilder<T>where
T: Pdu,
Creates a new FrameBuilder.
Sourcepub fn validate_crc(&self) -> Result<(), CrcError>
pub fn validate_crc(&self) -> Result<(), CrcError>
Validates the CRC of the frame. Self::into_data will also validate
the CRC, so in most cases you should not need to call this method
directly.