pub struct FrameBuilder<T> { /* private fields */ }Expand description
A builder for Frames.
Implementations
Sourceimpl<T: Pdu> FrameBuilder<T>
impl<T: Pdu> FrameBuilder<T>
Sourcepub const fn with_pdu(unit_id: u8, pdu: T) -> Self
pub const fn with_pdu(unit_id: u8, pdu: T) -> Self
Creates a new builder with the given unit ID and PDU.
This is different from Frame::new in that no CRC is calculated at
this point.
Sourcepub const fn new(unit_id: u8) -> Self
pub const fn new(unit_id: u8) -> Self
Creates a new builder with the given unit ID and default PDU value.
Sourcepub const fn set_unit_id(&mut self, unit_id: u8)
pub const fn set_unit_id(&mut self, unit_id: u8)
Changes the unit ID.
Sourcepub fn build_ref(&mut self) -> &mut Frame<T>
pub fn build_ref(&mut self) -> &mut Frame<T>
Build a frame but don’t move it out of the builder, so that the builder can be recycled.